# 安装方式

    pip uninstall astmain  -y
    pip install     astmain

# 依赖包

    pip install requests
    pip install pyppeteer
    pip install pyppeteer_stealth

    pip install arrow

    pip install nuitka
    pip install pytoml
    pip install flit
